==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-freetype/Class_Span.cpp <==
#include "stdafx.h"

Gura_BeginModuleScope(freetype)

//-----------------------------------------------------------------------------
// Object_Span implementation
//-----------------------------------------------------------------------------
Object *Object_Span::Clone() const
{
	return NULL;
}

String Object_Span::ToString(bool exprFlag)
{
	char buff[80];
	::sprintf(buff, "<freetype.Span>");
	return String(buff);
}

bool Object_Span::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
{
	if (!Object::DoDirProp(env, sig, symbols)) return false;
#if 0
	symbols.insert(Gura_Symbol(x));
	symbols.insert(Gura_Symbol(y));
#endif
	return true;
}

Value Object_Span::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
						const SymbolSet &attrs, bool &evaluatedFlag)
{
	evaluatedFlag = true;
#if 0
	if (pSymbol->IsIdentical(Gura_Symbol(x))) {
		return Value(_vector.x);
	} else if (pSymbol->IsIdentical(Gura_Symbol(y))) {
		return Value(_vector.y);
	}
#endif
	evaluatedFlag = false;
	return Value::Null;
}

Value Object_Span::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
							const SymbolSet &attrs, bool &evaluatedFlag)
{
	evaluatedFlag = true;
#if 0
	if (pSymbol->IsIdentical(Gura_Symbol(x))) {
		if (!value.MustBe_number(sig)) return Value::Null;
		_vector.x = static_cast<FT_Pos>(value.GetLong());
		return Value(_vector.x);
	} else if (pSymbol->IsIdentical(Gura_Symbol(y))) {
		if (!value.MustBe_number(sig)) return Value::Null;
		_vector.y = static_cast<FT_Pos>(value.GetLong());
		return Value(_vector.y);
	}
#endif
	evaluatedFlag = false;
	return Value::Null;
}

//-----------------------------------------------------------------------------
// Class implementation for freetype.Span
//-----------------------------------------------------------------------------
Gura_ImplementUserClass(Span)
{
	Gura_AssignValue(Span, Value(Reference()));
}

Gura_EndModuleScope(freetype)

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-freetype/Class_Span.cpp <==
#include "stdafx.h"

Gura_BeginModuleScope(freetype)

//-----------------------------------------------------------------------------
// Object_Span implementation
//-----------------------------------------------------------------------------
Object *Object_Span::Clone() const
{
	return nullptr;
}

String Object_Span::ToString(bool exprFlag)
{
	char buff[80];
	::sprintf(buff, "<freetype.Span>");
	return String(buff);
}

//-----------------------------------------------------------------------------
// Implementation of properties
//-----------------------------------------------------------------------------
// freetype.Span#x
Gura_DeclareProperty_RW(Span, x)
{
	SetPropAttr(VTYPE_any);
	AddHelp(
		Gura_Symbol(en),
		""
		);
}

Gura_ImplementPropertyGetter(Span, x)
{
	return Value::Nil;
}

Gura_ImplementPropertySetter(Span, x)
{
	return Value::Nil;
}

// freetype.Span#y
Gura_DeclareProperty_RW(Span, y)
{
	SetPropAttr(VTYPE_any);
	AddHelp(
		Gura_Symbol(en),
		""
		);
}

Gura_ImplementPropertyGetter(Span, y)
{
	return Value::Nil;
}

Gura_ImplementPropertySetter(Span, y)
{
	return Value::Nil;
}

//-----------------------------------------------------------------------------
// Class implementation for freetype.Span
//-----------------------------------------------------------------------------
Gura_ImplementUserClass(Span)
{
	// Assignment of properties
#if 0
	Gura_AssignProperty(Span, x);
	Gura_AssignProperty(Span, y);
#endif
	Gura_AssignValue(Span, Value(Reference()));
}

Gura_EndModuleScope(freetype)
